Changes log
===========

1.0.0a2
-------

- Fixed packaging issue
  [glenfant]

1.0.0a1
-------

No changes. Just a version normalization.

1.0.0.a1
--------

First release.

- Package creation with ``bobtemplates.gillux``
  [glenfant]
